#ifndef BPSPlayer_h 
#define BPSPlayer_h 

#import <WebKit/WebKit.h>
#import <Foundation/Foundation.h>
#import "BPSMPlayerConfig.h"
#import "BPSMMedia.h"
#import "BPSPlayerDelegate.h"

//! Main bradmax player class.
@interface BPSPlayer : WKWebView <WKScriptMessageHandler, WKNavigationDelegate, WKUIDelegate, UIScrollViewDelegate>

@property(readonly) BPSMPlayerConfig *playerConfig;

//! When this identifier is defined, then player version is loaded from bradmax platform.
//!
//! This identifier can be found on bradmax player on "get embed code" page. In iframe embed code
//! there is a src parameter with URL with form
//! "https://bradmax.com/client/embed-player/[PLAYER_BUILD_ID]?mediaUrl=[MEDIA_URL]"
//! eg.
//! "https://bradmax.com/client/embed-player/d5a43836d238bb46d0a0b046267175975a9d6222_4013?mediaUrl=https%3A%2F%2Fbradmax.com%2Fstatic%2Fvideo%2Ftears_of_steel.mp4"
//!
//! Searched [PLAYER_BUILD_ID] is placed just after "/embed-player/" text. Just copy it and
//! call setRemoteBradmaxPlayerEmbedId(). For example above it would be
//! player.remoteBradmaxPlayerEmbedId = @"d5a43836d238bb46d0a0b046267175975a9d6222_4013";
@property NSString *remoteBradmaxPlayerEmbedId;

//! Set customized bradmax JavaScript player asset file.
@property NSString *localBradmaxPlayerJs;

// Private / internal use only settings.
@property NSString *_bradmaxPlayerVersion;
@property BOOL _hasPlayerLoaded;
@property NSMutableArray *_jsScriptsOnPlayerPageLoad;

// - Fullscreen support internal properties.
@property BOOL _isInFullscreen;
@property CGRect _fullscreenBackFrame;
@property UIViewAutoresizing _fullscreenBackAutoresizingMask;
@property UIView *_fullscreenBackSuperview;
@property NSUInteger _fullscreenBackIndexInSuperview;

//! Player delegate for handling player events.
@property(nonatomic, weak) id <BPSPlayerDelegate> playerDelegate;

//! Simple API for quick and easy opening video. Only stream URL is required (mediaSourceUrl).
//! Type of stream will be automatically detected by player. When posterUrl is passed, then
//! poster image will be present on player area, before starting playback.
//!
//! @param mediaSourceUrl Video stream URL.
//! @param posterUrl (optional) Poser image URL for showing before playback.
- (void)loadVideoByUrl: (NSString *)mediaSourceUrl
         withPosterUrl:(NSString *)posterUrl;

//! Simple API for quick and easy opening video. Only stream URL is required (mediaSourceUrl).
//! Type of stream will be automatically detected by player.
//!
//! @param mediaSourceUrl Video stream URL.
- (void)loadVideoByUrl: (NSString *)mediaSourceUrl;

//! Adds media object into player playback list.
//!
//! @param media Media object for adding to end of playback list.
- (void) addMediaToPlayback:(BPSMMedia *)media;

//! Clears player playback list.
- (void) clearPlaybackList;

//! Return player current configured Media playlist.
//!
//! @return array with Media objects.
- (NSMutableArray *) getPlaybackList;

//! Loads into WebView configured before player. Before load you can setup playlist and general
//! player settings like autoplay. After load complete process (asynchronious task) player API
//! calls are possible.
- (void) load;

//! Get player version
//!
//! @return verion number as string
- (NSString *) getVersion;

//! Starts media playback.
//! IMPORTANT: Requires loading player before (call load() or loadVideoByUrl()).
- (void) play;

//! Pause media playback.
//! IMPORTANT: Requires loading player before (call load() or loadVideoByUrl()).
- (void) pause;

//! Toggle between play and pause. If player is in ‘pause’ state, this command will start media playback. If player is in ‘play’ state, this command will pause media playback.
//! IMPORTANT: Requires loading player before (call load() or loadVideoByUrl()).
- (void) playPause;

//! Seek media to time position in seconds.
//! IMPORTANT: Requires loading player before (call load() or loadVideoByUrl()).
//!
//! @param position Video position to seek in seconds.
- (void)seek:(double) position;

//! Set volume, accept value in range from 0 to 1, example: 0.75.
//! MPORTANT: Requires loading player before (call load() or loadVideoByUrl()).
//!
//! @param volume Volume ratio (0.0 - muted sound, 1.0 - full volume)
- (void)setVolume:(double) volume;

//! Toggle fullscreen mode.
- (void) toggleFullscreen;

@end
#endif
